[ob/pushed] Fix typos in gdb_pipe function comment

Message ID 1462316851-19956-1-git-send-email-donb@codesourcery.com
State New, archived
Headers

Commit Message

Don Breazeal May 3, 2016, 11:07 p.m. UTC
  This patch fixes mis-typed argument names in the function
comment for gdb_pipe.  Committed as obvious.
Thanks
--Don

gdb/ChangeLog:
2016-05-03  Don Breazeal <donb@codesourcery.com>

	* serial.h (gdb_pipe): Fix argument names in comment.

---
 gdb/ChangeLog | 4 ++++
 gdb/serial.h  | 4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)
  

Patch

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 8627cb7..78b3abb 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,7 @@ 
+2016-05-03  Don Breazeal <donb@codesourcery.com>
+
+	* serial.h (gdb_pipe): Fix argument names in comment.
+
 2016-05-03  Pedro Alves <palves@redhat.com>
 
 	PR python/20037
diff --git a/gdb/serial.h b/gdb/serial.h
index 10b0643..84373f5 100644
--- a/gdb/serial.h
+++ b/gdb/serial.h
@@ -75,8 +75,8 @@  extern void serial_ref (struct serial *scb);
 
 extern void serial_unref (struct serial *scb);
 
-/* Create a pipe, and put the read end in files[0], and the write end
-   in filde[1].  Returns 0 for success, negative value for error (in
+/* Create a pipe, and put the read end in FILDES[0], and the write end
+   in FILDES[1].  Returns 0 for success, negative value for error (in
    which case errno contains the error).  */
 
 extern int gdb_pipe (int fildes[2]);